pub enum DiagnosticAdmission {
Accepted,
Unavailable,
Exhausted,
Closed,
}Expand description
A bounded admission outcome safe to expose to a diagnostic observer.
Variants
Accepted
The value or operation entered the selected bounded queue.
The selected provider or subscriber generation is unavailable.
Exhausted
The selected bounded queue is full.
Closed
App admission was already closed.