pub enum ExecutionAdapterCatalogError {
DuplicateExecutionClass {
execution_class: String,
},
}Expand description
A Runner could not assemble one unambiguous Adapter catalog.
Variants
DuplicateExecutionClass
More than one installed Adapter claimed the same execution class.