pub enum InvocationContextError {
EmptyExtensionKey,
ExtensionAlreadySet {
key: String,
},
SealedExtensionAlreadySet {
key: String,
},
InvalidSealedExtension {
key: String,
},
}Expand description
Failure returned when an Invocation Context extension cannot be attached.
Variants
EmptyExtensionKey
An extension key cannot be empty.
ExtensionAlreadySet
An ordinary extension already occupies the requested key.
SealedExtensionAlreadySet
A sealed extension cannot be replaced by another extension value.
InvalidSealedExtension
Sealed provenance must name an issuer and at least one audience entry.