pub enum ModuleLifecyclePhase {
Prepare,
Activate,
Ready,
Deactivate,
}Expand description
The lifecycle phase represented by a Module context.
Variants
Prepare
The Module may validate configuration and reserve reversible resources.
Activate
The Module may initialize against already prepared dependencies.
Ready
The App Ready Gate has opened and externally triggered work may begin.
Deactivate
The Module must release work and resources owned by this generation.