pub enum PlanValidationError {
UnsupportedSchemaVersion {
expected: u32,
actual: u32,
},
InvalidResolvedPlan {
detail: String,
},
}Expand description
A reason the Kernel rejected a Resolved App Plan before boot.
Variants
UnsupportedSchemaVersion
The Plan schema cannot be executed by this Kernel version.
InvalidResolvedPlan
The Plan graph is structurally invalid and cannot be booted.