pub enum ResourceRegistrationError {
ScopeClosed,
}Expand description
Error returned when a resource cannot be registered in a closed scope.
Variants
ScopeClosed
The Module generation has begun shutdown or rollback cleanup.