TerminalOutcome

Enum TerminalOutcome 

pub enum TerminalOutcome {
    CleanShutdown,
    StartupFailure {
        error: RuntimeFailure,
    },
    RuntimeFailure {
        error: RuntimeFailure,
    },
    RuntimeFailureDuringShutdown {
        error: RuntimeFailure,
        cleanup_error: RuntimeFailure,
    },
    RuntimeFailureWithShutdownTimeout {
        error: RuntimeFailure,
    },
    ShutdownTimeout,
}
A successful terminal result returned to the embedding Runner.

Variants



CleanShutdown

The App completed a bounded clean shutdown.



StartupFailure

The App could not start because a Module reported a startup failure.

Fields



RuntimeFailure

The running App reported a Runtime Failure during terminal cleanup.

Fields



RuntimeFailureDuringShutdown

The running App failed and cleanup reported a second Runtime Failure.

Fields

cleanup_error: RuntimeFailure


RuntimeFailureWithShutdownTimeout

The running App failed and cleanup then exceeded its global deadline.

Fields



ShutdownTimeout

The App exceeded its one global shutdown deadline.