pub struct ActivateContext { /* private fields */ }Expand description
Context supplied while a Module initializes against prepared dependencies.
Implementations
Sourceimpl ActivateContext
impl ActivateContext
Sourcepub fn instance_key(&self) -> &str
pub fn instance_key(&self) -> &str
Returns the App-local Module Instance key.
Sourcepub const fn phase(&self) -> ModuleLifecyclePhase
pub const fn phase(&self) -> ModuleLifecyclePhase
Returns the phase represented by this context.
Sourcepub fn dependencies(&self) -> &ModuleDependencies
pub fn dependencies(&self) -> &ModuleDependencies
Returns the explicit dependencies selected for this Instance.
Sourcepub fn ready_gate(&self) -> AppReadyGate
pub fn ready_gate(&self) -> AppReadyGate
Returns the closed-until-fully-active App Ready Gate.
Sourcepub fn readiness(&self) -> ReadinessContext
pub fn readiness(&self) -> ReadinessContext
Returns the readiness context a Module may pass to managed work.
Sourcepub fn tasks(&self) -> &ManagedTaskScope
pub fn tasks(&self) -> &ManagedTaskScope
Returns the generation-owned task scope.
Sourcepub fn resources(&self) -> &ManagedResourceScope
pub fn resources(&self) -> &ManagedResourceScope
Returns the generation-owned resource scope.
Sourcepub fn cancellation(&self) -> CancellationToken
pub fn cancellation(&self) -> CancellationToken
Returns the generation-owned cooperative cancellation token.
Sourcepub fn admission(&self) -> AppAdmission
pub fn admission(&self) -> AppAdmission
Returns the App admission state, which remains closed until readiness.