pub struct ManagedResourceScope { /* private fields */ }Expand description
A Module-generation resource scope backed by Driver-polled cleanup futures.
Implementations
Sourceimpl ManagedResourceScope
impl ManagedResourceScope
Sourcepub fn register(
&self,
resource: impl ManagedResource,
) -> Result<ManagedResourceHandle, ResourceRegistrationError>
pub fn register( &self, resource: impl ManagedResource, ) -> Result<ManagedResourceHandle, ResourceRegistrationError>
Registers a resource owned by this Module Instance generation.
Sourcepub fn resource_count(&self) -> usize
pub fn resource_count(&self) -> usize
Returns the number of resources that still need cleanup.