pub struct ManagedTaskScope { /* private fields */ }Expand description
A Module-generation task scope backed by the selected Runtime Driver.
Implementations
Sourceimpl ManagedTaskScope
impl ManagedTaskScope
Sourcepub fn spawn_local(
&self,
task: LocalTask,
) -> Result<ManagedTask, ManagedTaskError>
pub fn spawn_local( &self, task: LocalTask, ) -> Result<ManagedTask, ManagedTaskError>
Spawns work owned by this Module Instance generation.
Sourcepub fn task_count(&self) -> usize
pub fn task_count(&self) -> usize
Returns the number of tasks still tracked by this scope.
Sourcepub fn cancellation(&self) -> CancellationToken
pub fn cancellation(&self) -> CancellationToken
Returns the cooperative cancellation token for this generation.