pub struct ModuleDependencyHandle { /* private fields */ }Expand description
An opaque, Adapter-resolved Capability endpoint passed to lifecycle code.
Implementations
Sourceimpl ModuleDependencyHandle
impl ModuleDependencyHandle
Sourcepub fn capability_id(&self) -> &'static str
pub fn capability_id(&self) -> &'static str
Returns the Capability implemented by this handle.
Sourcepub fn descriptor_version(&self) -> &'static str
pub fn descriptor_version(&self) -> &'static str
Returns the exact Descriptor version implemented by this handle.
Sourcepub fn operations(&self) -> &'static [&'static str]
pub fn operations(&self) -> &'static [&'static str]
Returns the exact Operation table implemented by this handle.
Sourcepub fn typed<C: RequestCapability>(
&self,
) -> Result<NativeRequestHandle<C>, RuntimeFailure>
pub fn typed<C: RequestCapability>( &self, ) -> Result<NativeRequestHandle<C>, RuntimeFailure>
Converts this resolved dependency into its generated typed request handle.