pub struct NativeEndpointSet { /* private fields */ }Expand description
The complete native endpoint set owned by one Plugin generation.
Implementations
Sourceimpl NativeEndpointSet
impl NativeEndpointSet
Sourcepub fn new(
request: Vec<Rc<dyn NativeRequestEndpoint>>,
stream: Vec<Rc<dyn NativeStreamEndpoint>>,
event: Vec<Rc<dyn NativeEventEndpoint>>,
) -> Self
pub fn new( request: Vec<Rc<dyn NativeRequestEndpoint>>, stream: Vec<Rc<dyn NativeStreamEndpoint>>, event: Vec<Rc<dyn NativeEventEndpoint>>, ) -> Self
Creates an endpoint set containing every native interaction kind.
Sourcepub fn request(&self) -> &[Rc<dyn NativeRequestEndpoint>]
pub fn request(&self) -> &[Rc<dyn NativeRequestEndpoint>]
Returns the request endpoints in this generation.
Sourcepub fn stream(&self) -> &[Rc<dyn NativeStreamEndpoint>]
pub fn stream(&self) -> &[Rc<dyn NativeStreamEndpoint>]
Returns the stream endpoints in this generation.
Sourcepub fn event(&self) -> &[Rc<dyn NativeEventEndpoint>]
pub fn event(&self) -> &[Rc<dyn NativeEventEndpoint>]
Returns the Event endpoints in this generation.