pub struct NativeStreamHandle<C: StreamCapability> { /* private fields */ }Expand description
Typed, immutable stream endpoints materialized before App boot completes.
Implementations
Sourceimpl<C: StreamCapability> NativeStreamHandle<C>
impl<C: StreamCapability> NativeStreamHandle<C>
Sourcepub fn binding_count(&self) -> usize
pub fn binding_count(&self) -> usize
Returns the number of provider endpoints captured by this handle.
Sourcepub async fn open(
&self,
operation: &str,
request: C::OpenRequest,
) -> Result<Result<NativeStream<C>, C::DomainError>, RuntimeFailure>
pub async fn open( &self, operation: &str, request: C::OpenRequest, ) -> Result<Result<NativeStream<C>, C::DomainError>, RuntimeFailure>
Opens one stream with a fresh invocation context.
Sourcepub async fn open_with_context(
&self,
operation: &str,
context: InvocationContext,
request: C::OpenRequest,
) -> Result<Result<NativeStream<C>, C::DomainError>, RuntimeFailure>
pub async fn open_with_context( &self, operation: &str, context: InvocationContext, request: C::OpenRequest, ) -> Result<Result<NativeStream<C>, C::DomainError>, RuntimeFailure>
Opens one stream with an explicit propagated Invocation Context.