pub struct PluginDependencies { /* private fields */ }Expand description
The explicit Capability dependencies available during Plugin lifecycle.
Implementations
Sourceimpl PluginDependencies
impl PluginDependencies
Sourcepub fn bindings(&self) -> &[PluginDependency]
pub fn bindings(&self) -> &[PluginDependency]
Returns dependencies in the order materialized by the Resolved App Plan.
Sourcepub fn invocation_context(
&self,
deadline: Option<Duration>,
cancellation: CancellationToken,
) -> Result<InvocationContext, RuntimeFailure>
pub fn invocation_context( &self, deadline: Option<Duration>, cancellation: CancellationToken, ) -> Result<InvocationContext, RuntimeFailure>
Creates a Kernel Invocation Context for work initiated by this Plugin.
The request identity and monotonic deadline come from the same Runtime Driver as the App. The context is still owned by the caller and its cancellation token remains explicit.
Sourcepub fn invocation_context_after(
&self,
timeout: Duration,
cancellation: CancellationToken,
) -> Result<InvocationContext, RuntimeFailure>
pub fn invocation_context_after( &self, timeout: Duration, cancellation: CancellationToken, ) -> Result<InvocationContext, RuntimeFailure>
Creates a Plugin Invocation Context with a Driver-relative deadline.
Sourcepub fn one<C: RequestCapability>(
&self,
) -> Result<NativeRequestHandle<C>, RuntimeFailure>
pub fn one<C: RequestCapability>( &self, ) -> Result<NativeRequestHandle<C>, RuntimeFailure>
Returns the one explicitly bound typed dependency.
Sourcepub fn optional<C: RequestCapability>(
&self,
) -> Result<Option<NativeRequestHandle<C>>, RuntimeFailure>
pub fn optional<C: RequestCapability>( &self, ) -> Result<Option<NativeRequestHandle<C>>, RuntimeFailure>
Returns an optional explicitly bound typed dependency.
Sourcepub fn many<C: RequestCapability>(
&self,
) -> Result<Vec<NativeRequestHandle<C>>, RuntimeFailure>
pub fn many<C: RequestCapability>( &self, ) -> Result<Vec<NativeRequestHandle<C>>, RuntimeFailure>
Returns all explicitly bound typed dependencies in resolved provider order.
Sourcepub fn one_stream<C: StreamCapability>(
&self,
) -> Result<NativeStreamHandle<C>, RuntimeFailure>
pub fn one_stream<C: StreamCapability>( &self, ) -> Result<NativeStreamHandle<C>, RuntimeFailure>
Returns the one explicitly bound typed stream dependency.
Sourcepub fn optional_stream<C: StreamCapability>(
&self,
) -> Result<Option<NativeStreamHandle<C>>, RuntimeFailure>
pub fn optional_stream<C: StreamCapability>( &self, ) -> Result<Option<NativeStreamHandle<C>>, RuntimeFailure>
Returns an optional explicitly bound typed stream dependency.
Sourcepub fn many_stream<C: StreamCapability>(
&self,
) -> Result<Vec<NativeStreamHandle<C>>, RuntimeFailure>
pub fn many_stream<C: StreamCapability>( &self, ) -> Result<Vec<NativeStreamHandle<C>>, RuntimeFailure>
Returns all explicitly bound typed stream dependencies in Plan order.
Sourcepub fn many_event<C: EventCapability>(
&self,
) -> Result<NativeEventHandle<C>, RuntimeFailure>
pub fn many_event<C: EventCapability>( &self, ) -> Result<NativeEventHandle<C>, RuntimeFailure>
Returns one typed Event handle over every explicit binding in Plan order.
Sourcepub fn one_event<C: EventCapability>(
&self,
) -> Result<NativeEventHandle<C>, RuntimeFailure>
pub fn one_event<C: EventCapability>( &self, ) -> Result<NativeEventHandle<C>, RuntimeFailure>
Returns the one explicitly bound typed Event dependency.
Sourcepub fn optional_event<C: EventCapability>(
&self,
) -> Result<Option<NativeEventHandle<C>>, RuntimeFailure>
pub fn optional_event<C: EventCapability>( &self, ) -> Result<Option<NativeEventHandle<C>>, RuntimeFailure>
Returns an optional explicitly bound typed Event dependency.