pub struct PluginDependency { /* private fields */ }Expand description
A deterministic dependency visible to one Plugin Instance.
Implementations
Sourceimpl PluginDependency
impl PluginDependency
Sourcepub fn capability_id(&self) -> &str
pub fn capability_id(&self) -> &str
Returns the Capability required by this dependency.
Sourcepub fn provider_instance(&self) -> &str
pub fn provider_instance(&self) -> &str
Returns the App-local provider Instance key.
Sourcepub const fn provider_order(&self) -> usize
pub const fn provider_order(&self) -> usize
Returns the deterministic provider order for a many binding.
Sourcepub fn handle(&self) -> Option<PluginDependencyHandle>
pub fn handle(&self) -> Option<PluginDependencyHandle>
Returns the resolved native endpoint handle when the Adapter supplied one.
Sourcepub fn stream_handle(&self) -> Option<PluginStreamDependencyHandle>
pub fn stream_handle(&self) -> Option<PluginStreamDependencyHandle>
Returns the resolved native stream endpoint handle when the Adapter supplied one.
Sourcepub fn event_handle(&self) -> Option<PluginEventDependencyHandle>
pub fn event_handle(&self) -> Option<PluginEventDependencyHandle>
Returns the resolved native Event endpoint handle when the Adapter supplied one.