pub struct PluginDependencyHandle { /* private fields */ }Expand description
An opaque, Adapter-resolved Capability endpoint passed to lifecycle code.
Implementations
Sourceimpl PluginDependencyHandle
impl PluginDependencyHandle
Sourcepub fn capability_id(&self) -> &'static str
pub fn capability_id(&self) -> &'static str
Returns the Capability implemented by this handle.
Sourcepub fn descriptor_version(&self) -> &'static str
pub fn descriptor_version(&self) -> &'static str
Returns the exact Descriptor version implemented by this handle.
Sourcepub fn operations(&self) -> &'static [&'static str]
pub fn operations(&self) -> &'static [&'static str]
Returns the exact Operation table implemented by this handle.
Sourcepub fn invoke_erased(
&self,
operation: &str,
request: Box<dyn Any>,
context: InvocationContext,
) -> LocalBoxFuture<'static, Result<Result<Box<dyn Any>, Box<dyn Any>>, RuntimeFailure>>
pub fn invoke_erased( &self, operation: &str, request: Box<dyn Any>, context: InvocationContext, ) -> LocalBoxFuture<'static, Result<Result<Box<dyn Any>, Box<dyn Any>>, RuntimeFailure>>
Invokes this exact resolved dependency through Kernel admission and supervision.
Language Execution Adapters use this after their generated codec has decoded a portable request into the provider’s native erased value.
Sourcepub fn typed<C: RequestCapability>(
&self,
) -> Result<NativeRequestHandle<C>, RuntimeFailure>
pub fn typed<C: RequestCapability>( &self, ) -> Result<NativeRequestHandle<C>, RuntimeFailure>
Converts this resolved dependency into its generated typed request handle.