pub struct PluginEventDependencyHandle { /* private fields */ }Expand description
An opaque Event endpoint passed to Plugin lifecycle code.
Implementations
Sourceimpl PluginEventDependencyHandle
impl PluginEventDependencyHandle
Sourcepub fn capability_id(&self) -> &'static str
pub fn capability_id(&self) -> &'static str
Returns the Capability implemented by this handle.
Sourcepub fn descriptor_version(&self) -> &'static str
pub fn descriptor_version(&self) -> &'static str
Returns the exact Descriptor version implemented by this handle.
Sourcepub fn operations(&self) -> &'static [&'static str]
pub fn operations(&self) -> &'static [&'static str]
Returns the exact Event Operation table implemented by this handle.
Sourcepub fn typed<C: EventCapability>(
&self,
) -> Result<NativeEventHandle<C>, RuntimeFailure>
pub fn typed<C: EventCapability>( &self, ) -> Result<NativeEventHandle<C>, RuntimeFailure>
Converts this resolved dependency into its generated typed Event handle.