pub struct PluginStreamDependencyHandle { /* private fields */ }Expand description
An opaque, Adapter-resolved stream Capability endpoint passed to lifecycle code.
Implementations
Sourceimpl PluginStreamDependencyHandle
impl PluginStreamDependencyHandle
Sourcepub fn capability_id(&self) -> &'static str
pub fn capability_id(&self) -> &'static str
Returns the Capability implemented by this stream handle.
Sourcepub fn descriptor_version(&self) -> &'static str
pub fn descriptor_version(&self) -> &'static str
Returns the exact Descriptor version implemented by this stream handle.
Sourcepub fn operations(&self) -> &'static [&'static str]
pub fn operations(&self) -> &'static [&'static str]
Returns the exact stream Operation table implemented by this handle.
Sourcepub fn typed<C: StreamCapability>(
&self,
) -> Result<NativeStreamHandle<C>, RuntimeFailure>
pub fn typed<C: StreamCapability>( &self, ) -> Result<NativeStreamHandle<C>, RuntimeFailure>
Converts this resolved dependency into its generated typed stream handle.