pub struct PreparedBinding { /* private fields */ }Expand description
One provider-specific binding prepared by an Execution Adapter.
Implementations
Sourceimpl PreparedBinding
impl PreparedBinding
Sourcepub fn new(
consumer_instance: impl Into<String>,
provider_instance: impl Into<String>,
endpoint: Rc<dyn NativeRequestEndpoint>,
) -> Self
pub fn new( consumer_instance: impl Into<String>, provider_instance: impl Into<String>, endpoint: Rc<dyn NativeRequestEndpoint>, ) -> Self
Binds one consumer to the endpoint prepared for one exact provider Instance.
Sourcepub fn consumer_instance(&self) -> &str
pub fn consumer_instance(&self) -> &str
Returns the App-local consumer Instance selected by the Plan.
Sourcepub fn provider_instance(&self) -> &str
pub fn provider_instance(&self) -> &str
Returns the App-local provider Instance selected by the Plan.
Sourcepub fn endpoint(&self) -> Rc<dyn NativeRequestEndpoint>
pub fn endpoint(&self) -> Rc<dyn NativeRequestEndpoint>
Returns the exact prepared endpoint referenced by this binding.