pub struct PreparedEventBinding { /* private fields */ }Expand description
One provider-specific ephemeral Event binding prepared by an Adapter.
Implementations
Sourceimpl PreparedEventBinding
impl PreparedEventBinding
Sourcepub fn new(
consumer_instance: impl Into<String>,
provider_instance: impl Into<String>,
endpoint: Rc<dyn NativeEventEndpoint>,
) -> Self
pub fn new( consumer_instance: impl Into<String>, provider_instance: impl Into<String>, endpoint: Rc<dyn NativeEventEndpoint>, ) -> Self
Binds one consumer to one exact Event endpoint and provider Instance.
Sourcepub fn consumer_instance(&self) -> &str
pub fn consumer_instance(&self) -> &str
Returns the App-local consumer Instance selected by the Plan.
Sourcepub fn provider_instance(&self) -> &str
pub fn provider_instance(&self) -> &str
Returns the App-local provider Instance selected by the Plan.
Sourcepub fn endpoint(&self) -> Rc<dyn NativeEventEndpoint>
pub fn endpoint(&self) -> Rc<dyn NativeEventEndpoint>
Returns the exact prepared Event endpoint referenced by this binding.