pub struct PreparedNativeApp { /* private fields */ }Expand description
Prepared native bindings returned by an Execution Adapter to Kernel.
Implementations
Sourceimpl PreparedNativeApp
impl PreparedNativeApp
Sourcepub fn new(
bindings: Vec<PreparedBinding>,
generations: BTreeMap<String, PreparedNativeModule>,
) -> Self
pub fn new( bindings: Vec<PreparedBinding>, generations: BTreeMap<String, PreparedNativeModule>, ) -> Self
Completes Adapter preparation with the full generation and binding tables.
Sourcepub fn with_stream_bindings(
self,
stream_bindings: Vec<PreparedStreamBinding>,
) -> Self
pub fn with_stream_bindings( self, stream_bindings: Vec<PreparedStreamBinding>, ) -> Self
Adds the exact bidirectional stream bindings prepared by an Adapter.
Sourcepub fn with_event_bindings(
self,
event_bindings: Vec<PreparedEventBinding>,
) -> Self
pub fn with_event_bindings( self, event_bindings: Vec<PreparedEventBinding>, ) -> Self
Adds the exact ephemeral Event bindings prepared by an Adapter.