pub struct PreparedStreamBinding { /* private fields */ }Expand description
One provider-specific bidirectional stream binding prepared by an Adapter.
Implementations
Sourceimpl PreparedStreamBinding
impl PreparedStreamBinding
Sourcepub fn new(
consumer_instance: impl Into<String>,
provider_instance: impl Into<String>,
endpoint: Rc<dyn NativeStreamEndpoint>,
) -> Self
pub fn new( consumer_instance: impl Into<String>, provider_instance: impl Into<String>, endpoint: Rc<dyn NativeStreamEndpoint>, ) -> Self
Binds one consumer to one exact stream endpoint and provider Instance.
Sourcepub fn consumer_instance(&self) -> &str
pub fn consumer_instance(&self) -> &str
Returns the App-local consumer Instance selected by the Plan.
Sourcepub fn provider_instance(&self) -> &str
pub fn provider_instance(&self) -> &str
Returns the App-local provider Instance selected by the Plan.
Sourcepub fn endpoint(&self) -> Rc<dyn NativeStreamEndpoint>
pub fn endpoint(&self) -> Rc<dyn NativeStreamEndpoint>
Returns the exact prepared stream endpoint referenced by this binding.