pub struct ReadinessContext { /* private fields */ }Expand description
Context supplied after the App Ready Gate has opened.
Implementations
Sourceimpl ReadinessContext
impl ReadinessContext
Sourcepub fn instance_key(&self) -> &str
pub fn instance_key(&self) -> &str
Returns the App-local Module Instance key.
Sourcepub const fn phase(&self) -> ModuleLifecyclePhase
pub const fn phase(&self) -> ModuleLifecyclePhase
Returns the phase represented by this context.
Sourcepub fn dependencies(&self) -> &ModuleDependencies
pub fn dependencies(&self) -> &ModuleDependencies
Returns the explicit dependencies selected for this Instance.
Sourcepub fn ready_gate(&self) -> AppReadyGate
pub fn ready_gate(&self) -> AppReadyGate
Returns the opened App Ready Gate.
Sourcepub fn wait(&self) -> LocalBoxFuture<'static, ()>
pub fn wait(&self) -> LocalBoxFuture<'static, ()>
Waits for the App Ready Gate to open.
Sourcepub fn tasks(&self) -> &ManagedTaskScope
pub fn tasks(&self) -> &ManagedTaskScope
Returns the generation-owned task scope.
Sourcepub fn resources(&self) -> &ManagedResourceScope
pub fn resources(&self) -> &ManagedResourceScope
Returns the generation-owned resource scope.
Sourcepub fn cancellation(&self) -> CancellationToken
pub fn cancellation(&self) -> CancellationToken
Returns the generation-owned cooperative cancellation token.
Sourcepub fn is_accepting(&self) -> bool
pub fn is_accepting(&self) -> bool
Returns whether new externally triggered work may be admitted.
Sourcepub fn admission(&self) -> AppAdmission
pub fn admission(&self) -> AppAdmission
Returns the App admission state.