pub struct RuntimeDiagnostics { /* private fields */ }Expand description
An opt-in Runtime Diagnostics port.
The port only stores local, ephemeral, best-effort records. It never calls observer code and never waits for a consumer. It is therefore unsuitable for audit, durable Story correctness, persistence, replay, or redelivery.
Implementations
Sourceimpl RuntimeDiagnostics
impl RuntimeDiagnostics
Sourcepub fn subscribe(
&self,
filter: DiagnosticFilter,
capacity: usize,
) -> Result<DiagnosticObserver, DiagnosticSubscribeError>
pub fn subscribe( &self, filter: DiagnosticFilter, capacity: usize, ) -> Result<DiagnosticObserver, DiagnosticSubscribeError>
Adds an independently bounded, source-filtered observer queue.
Sourcepub fn subscribe_all(
&self,
capacity: usize,
) -> Result<DiagnosticObserver, DiagnosticSubscribeError>
pub fn subscribe_all( &self, capacity: usize, ) -> Result<DiagnosticObserver, DiagnosticSubscribeError>
Adds an all-source observer queue.
Sourcepub fn observer_count(&self) -> usize
pub fn observer_count(&self) -> usize
Returns the number of observers that are still connected to this port.