pub type ModuleFuture = LocalBoxFuture<'static, Result<(), RuntimeFailure>>;Expand description
The result type returned by prepare, activate, and deactivate hooks.
Aliased Type
#[repr(transparent)]pub struct ModuleFuture { /* private fields */ }pub type ModuleFuture = LocalBoxFuture<'static, Result<(), RuntimeFailure>>;The result type returned by prepare, activate, and deactivate hooks.
#[repr(transparent)]pub struct ModuleFuture { /* private fields */ }