pub enum PluginLifecyclePhase {
Prepare,
Activate,
Ready,
Deactivate,
}Expand description
The lifecycle phase represented by a Plugin context.
Variants
Prepare
The Plugin may validate configuration and reserve reversible resources.
Activate
The Plugin may initialize against already prepared dependencies.
Ready
The App Ready Gate has opened and externally triggered work may begin.
Deactivate
The Plugin must release work and resources owned by this generation.