pub enum TerminalOutcome {
CleanShutdown,
StartupFailure {
error: RuntimeFailure,
},
RuntimeFailure {
error: RuntimeFailure,
},
RuntimeFailureDuringShutdown {
error: RuntimeFailure,
cleanup_error: RuntimeFailure,
},
RuntimeFailureWithShutdownTimeout {
error: RuntimeFailure,
},
ShutdownTimeout,
}Expand description
A successful terminal result returned to the embedding Runner.
Variants
CleanShutdown
The App completed a bounded clean shutdown.
StartupFailure
The App could not start because a Module reported a startup failure.
Fields

error: RuntimeFailureRuntimeFailure
The running App reported a Runtime Failure during terminal cleanup.
Fields

error: RuntimeFailureRuntimeFailureDuringShutdown
The running App failed and cleanup reported a second Runtime Failure.
RuntimeFailureWithShutdownTimeout
The running App failed and cleanup then exceeded its global deadline.
Fields

error: RuntimeFailureShutdownTimeout
The App exceeded its one global shutdown deadline.