pub struct ExecutionAdapterCatalog { /* private fields */ }Expand description
Immutable Adapter catalog assembled by a Runner before Kernel boot.
Implementations
Sourceimpl ExecutionAdapterCatalog
impl ExecutionAdapterCatalog
Sourcepub fn single(adapter: impl ExecutionAdapter) -> Self
pub fn single(adapter: impl ExecutionAdapter) -> Self
Creates a catalog containing one Adapter package.
Sourcepub fn with_adapter(
self,
adapter: impl ExecutionAdapter,
) -> Result<Self, ExecutionAdapterCatalogError>
pub fn with_adapter( self, adapter: impl ExecutionAdapter, ) -> Result<Self, ExecutionAdapterCatalogError>
Installs one Adapter package under its open execution-class identity.
Installs an Adapter package discovered as a runtime trait object.
Sourcepub fn execution_classes(&self) -> ExecutionClassSet
pub fn execution_classes(&self) -> ExecutionClassSet
Returns the effective execution classes contributed by installed packages.